import { __assign, __rest } from "tslib";
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import * as React from "react";
import { Text } from "./Text";
import { CloseButton } from "./IconButton";
import { useTransition, animated } from "react-spring";
import { Overlay } from "./Overlay";
import { useFocusElement } from "./Hooks/use-focus-trap";
import PropTypes from "prop-types";
import useScrollLock from "use-scroll-lock";
import { useTheme } from "./Theme/Providers";
/**
 * A dialog is useful for displaying infomation that
 * commands the user's attention.
 */
export var Dialog = function (_a) {
    var isOpen = _a.isOpen, onRequestClose = _a.onRequestClose, mobileFullscreen = _a.mobileFullscreen, title = _a.title, children = _a.children, other = __rest(_a, ["isOpen", "onRequestClose", "mobileFullscreen", "title", "children"]);
    var theme = useTheme();
    // [TransitionFn<Item, State & object>, SpringStartFn<State>, SpringStopFn<State>]
    var transitions = useTransition(isOpen, {
        from: { opacity: 0, transform: "scale(0.9)" },
        enter: { opacity: 1, transform: "scale(1)" },
        leave: { opacity: 0, transform: "scale(0.9)" },
        config: { mass: 1, tension: 185, friction: 26 }
    });
    var scrollableRef = React.useRef(null);
    var ref = React.useRef(null);
    useFocusElement(ref, isOpen);
    useScrollLock(isOpen, scrollableRef);
    return (_jsx(React.Fragment, { children: _jsx(Overlay, __assign({ onRequestClose: onRequestClose, isOpen: isOpen }, { children: _jsx(React.Fragment, { children: transitions(function (style, item) {
                    var _a, _b;
                    return (item && _jsx(animated.div, __assign({ className: "Dialog", "aria-modal": "true", ref: ref, tabIndex: -1, onClick: function (e) {
                            e.stopPropagation();
                        }, style: {
                            opacity: style.opacity,
                            transform: style.transform
                        }, css: [
                            (_a = {
                                    zIndex: theme.zIndices.modal,
                                    background: theme.colors.background.default,
                                    boxShadow: theme.shadows.md,
                                    borderRadius: theme.radii.lg,
                                    margin: "16px",
                                    width: "calc(100% - 32px)",
                                    outline: "none"
                                },
                                _a[theme.mediaQueries.md] = {
                                    maxWidth: "500px",
                                    margin: "30px auto"
                                },
                                _a[theme.mediaQueries.lg] = {
                                    maxWidth: "650px",
                                    margin: "30px auto"
                                },
                                _a),
                            mobileFullscreen && (_b = {
                                    maxWidth: "none",
                                    margin: 0,
                                    width: "100vw",
                                    height: "100vh",
                                    borderRadius: 0,
                                    boxShadow: "none"
                                },
                                _b[theme.mediaQueries.md] = {
                                    maxWidth: "500px",
                                    margin: "30px auto",
                                    height: "auto",
                                    boxShadow: theme.shadows.md,
                                    borderRadius: theme.radii.lg,
                                    width: "calc(100% - 32px)"
                                },
                                _b)
                        ] }, other, { children: _jsxs(React.Fragment, { children: [title && (_jsx(DialogHeader, { className: "Dialog__header", css: {
                                        display: "flex",
                                        justifyContent: "space-between",
                                        alignItems: "center",
                                        padding: theme.spaces.lg + " " + theme.spaces.lg + " 0 " + theme.spaces.lg
                                    }, title: title, onRequestClose: onRequestClose }, void 0)),
                                _jsx("div", __assign({ ref: scrollableRef }, { children: children }), void 0)] }, void 0) }), 1));
                }) }, void 0) }), void 0) }, void 0));
};
Dialog.propTypes = {
    isOpen: PropTypes.bool.isRequired,
    onRequestClose: PropTypes.func.isRequired,
    title: PropTypes.string,
    mobileFullscreen: PropTypes.bool,
    children: PropTypes.node
};
export var DialogHeader = function (_a) {
    var title = _a.title, onRequestClose = _a.onRequestClose, other = __rest(_a, ["title", "onRequestClose"]);
    return (_jsxs("div", __assign({}, other, { children: [_jsx(Text, __assign({ wrap: false, variant: "h4" }, { children: title }), void 0),
            onRequestClose && _jsx(CloseButton, { onClick: onRequestClose }, void 0)] }), void 0));
};
DialogHeader.propTypes = {
    title: PropTypes.string.isRequired,
    onRequestClose: PropTypes.func
};
//# sourceMappingURL=Dialog.js.map