import { __assign, __rest } from "tslib";
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { Text } from "./Text";
import PropTypes from "prop-types";
import { MenuLabel } from "./Menu";
import { useTheme } from "./Theme/Providers";
import { noOp } from "./misc/noop";
import { useTouchable } from "touchable-hook";
import { safeBind } from "./Hooks/compose-bind";
export var List = function (_a) {
    var children = _a.children, other = __rest(_a, ["children"]);
    return _jsx("nav", __assign({}, other, { children: children }), void 0);
};
List.propTypes = {
    children: PropTypes.node
};
export var ListItem = function (_a) {
    var _b;
    var primary = _a.primary, secondary = _a.secondary, contentBefore = _a.contentBefore, _c = _a.interactive, interactive = _c === void 0 ? true : _c, children = _a.children, _d = _a.wrap, wrap = _d === void 0 ? true : _d, contentAfter = _a.contentAfter, _e = _a.onPress, onPress = _e === void 0 ? noOp : _e, _f = _a.component, Component = _f === void 0 ? "div" : _f, other = __rest(_a, ["primary", "secondary", "contentBefore", "interactive", "children", "wrap", "contentAfter", "onPress", "component"]);
    var interactiveProps = interactive
        ? {
            role: "button",
            tabIndex: 0
        }
        : {};
    var isLink = other.to || other.href;
    var _g = useTouchable({
        onPress: onPress,
        behavior: isLink ? "link" : "button"
    }), bind = _g.bind, hover = _g.hover, active = _g.active;
    var theme = useTheme();
    return (_jsx(Component, __assign({ className: "ListItem", css: [
            (_b = {
                    display: "block",
                    textDecoration: "none",
                    outline: "none",
                    padding: theme.spaces.md,
                    background: "transparent",
                    WebkitTapHighlightColor: "transparent",
                    transition: "background 0.07s ease"
                },
                _b[theme.mediaQueries.lg] = {
                    paddingLeft: theme.spaces.lg,
                    paddingRight: theme.spaces.lg
                },
                _b[":last-child"] = {
                    borderBottom: "none"
                },
                _b),
            interactive && {
                cursor: "pointer",
                ":focus": {
                    boxShadow: "inset 0 0 3px " + theme.colors.text.selected
                },
                ":focus:not([data-focus-visible-added])": {
                    boxShadow: "none"
                }
            },
            interactive &&
                hover && {
                background: theme.colors.background.tint1
            },
            interactive &&
                active && {
                background: theme.colors.background.tint2
            }
        ] }, interactiveProps, safeBind(interactive ? bind : {}, other), { children: _jsxs("div", __assign({ className: "ListItem__container", css: { display: "flex", alignItems: "center" } }, { children: [contentBefore && (_jsx("div", __assign({ className: "ListItem__content-before", css: { marginRight: theme.spaces.md } }, { children: contentBefore }), void 0)),
                _jsxs("div", __assign({ className: "ListItem__content", css: { flex: 1, overflow: "hidden" } }, { children: [_jsx(Text, __assign({ className: "ListItem__primary", wrap: wrap, variant: "body", css: { display: "block", fontWeight: 500 } }, { children: primary }), void 0),
                        secondary && (_jsx(Text, __assign({ className: "ListItem__secondary", wrap: wrap, css: { display: "block", fontSize: theme.fontSizes[0] }, variant: "body", muted: true }, { children: secondary }), void 0)), children] }), void 0),
                contentAfter && (_jsx("div", __assign({ className: "ListItem__content-after", css: { flex: "0 0 auto", marginLeft: theme.spaces.md } }, { children: contentAfter }), void 0))] }), void 0) }), void 0));
};
ListItem.propTypes = {
    primary: PropTypes.oneOfType([PropTypes.string, PropTypes.node]).isRequired,
    secondary: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
    contentBefore: PropTypes.node,
    contentAfter: PropTypes.node,
    wrap: PropTypes.bool,
    children: PropTypes.node,
    interactive: PropTypes.bool,
    onPress: PropTypes.func
};
export var ListSection = function (_a) {
    var _b;
    var title = _a.title, children = _a.children, _c = _a.sticky, sticky = _c === void 0 ? true : _c, other = __rest(_a, ["title", "children", "sticky"]);
    var theme = useTheme();
    var bg = theme.colors.background.layer;
    return (_jsxs("div", __assign({ css: {
            ":first-child > *": {
                borderTop: "none"
            }
        } }, { children: [_jsx(MenuLabel, __assign({ css: (_b = {
                        position: sticky ? "sticky" : "static",
                        top: 0,
                        backgroundColor: sticky ? bg : "transparent",
                        padding: theme.spaces.sm,
                        paddingLeft: theme.spaces.md,
                        marginTop: theme.spaces.md
                    },
                    _b[theme.mediaQueries.lg] = {
                        paddingLeft: theme.spaces.lg,
                        paddingRight: theme.spaces.lg
                    },
                    _b) }, other, { children: title }), void 0), children] }), void 0));
};
ListSection.propTypes = {
    title: PropTypes.string.isRequired,
    sticky: PropTypes.bool,
    children: PropTypes.node
};
//# sourceMappingURL=List.js.map